Examples
========

.. only:: html

    You can play with the Jupyter notebooks (without having to install anything)
    by clicking |binder logo| on the respective example page.

    .. |binder logo| image:: https://mybinder.org/badge_logo.svg
        :target: https://mybinder.org/v2/gh/sfstoolbox/sfs-python/master?
                 filepath=doc/examples

.. toctree::
    :maxdepth: 1

    examples/sound-field-synthesis
    examples/modal-room-acoustics
    examples/mirror-image-source-model
    examples/animations-pulsating-sphere
    example-python-scripts
